Max: Maximum of all the values present in its arguments.

View source: R/noNa.r

MaxR Documentation

Maximum of all the values present in its arguments.

Description

‘Max’ returns the maximum of all the values present in its arguments, omitting NA values. Useful to use inside apply functions to avoid errors due to NA's.

Usage

Max(x, ...)

Arguments

x

A vector containing numeric values

Value

A numeric scalar, the maximum of the inputs

Examples

x <- matrix(c((1:11)^2,NA), ncol=4)
apply(x,1,Max)


benjaminpeeters/BePe documentation built on July 7, 2022, 5:45 p.m.