iso2name: Load a Matrix

View source: R/iso.r

iso2nameR Documentation

Load a Matrix

Description

This function loads a file as a matrix. It assumes that the first column contains the rownames and the subsequent columns are the sample identifiers. Any rows with duplicated row names will be dropped with the first one being kepted.

Usage

iso2name(iso)

Arguments

infile

Path to the input file

Value

A matrix of the infile

See Also

Other iso3: countryNameShift(), incorrect.name2iso(), name2iso()


benjaminpeeters/BePe documentation built on July 7, 2022, 5:45 p.m.