| Max | R Documentation |
‘Max’ returns the maximum of all the values present in its arguments, omitting NA values. Useful to use inside apply functions to avoid errors due to NA's.
Max(x, ...)
x |
A vector containing numeric values |
A numeric scalar, the maximum of the inputs
x <- matrix(c((1:11)^2,NA), ncol=4) apply(x,1,Max)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.